@@ -1,5 +1,7 @@
 from .FinEquityVolCurve import *
+from .FinEquityVolSurface import *
 from .FinFXVolSurface import *
+from .FinFXVolSurfacePlus import *
 from .FinIborCapVolCurve import *
 
 
