@@ -23,7 +23,7 @@ from ...products.credit.FinCDSCurve import FinCDSCurve
 
 from ...finutils.FinGlobalVariables import gDaysInYear
 from ...finutils.FinMath import ONE_MILLION
-from ...market.curves.FinInterpolate import FinInterpTypes, interpolate
+from ...market.curves.FinInterpolator import FinInterpTypes, interpolate
 from ...finutils.FinError import FinError
 
 from ...finutils.FinHelperFunctions import checkArgumentTypes
@@ -53,7 +53,7 @@ class FinCDSTranche(object):
                  notional: float = ONE_MILLION,
                  runningCoupon: float = 0.0,
                  longProtection: bool = True,
-                 frequencyType: FinFrequencyTypes = FinFrequencyTypes.QUARTERLY,
+                 freqType: FinFrequencyTypes = FinFrequencyTypes.QUARTERLY,
                  dayCountType: FinDayCountTypes = FinDayCountTypes.ACT_360,
                  calendarType: FinCalendarTypes = FinCalendarTypes.WEEKEND,
                  busDayAdjustType: FinBusDayAdjustTypes = FinBusDayAdjustTypes.FOLLOWING,
@@ -75,7 +75,7 @@ class FinCDSTranche(object):
         self._dayCountType = dayCountType
         self._dateGenRuleType = dateGenRuleType
         self._calendarType = calendarType
-        self._frequencyType = frequencyType
+        self._freqType = freqType
         self._busDayAdjustType = busDayAdjustType
 
         notional = 1.0
@@ -85,7 +85,7 @@ class FinCDSTranche(object):
                                    self._runningCoupon,
                                    notional,
                                    self._longProtection,
-                                   self._frequencyType,
+                                   self._freqType,
                                    self._dayCountType,
                                    self._calendarType,
                                    self._busDayAdjustType,
@@ -161,7 +161,7 @@ class FinCDSTranche(object):
                 qRow = issuerCurve._values
                 recoveryRates[j] = issuerCurve._recoveryRate
                 qVector[j] = interpolate(
-                    t, vTimes, qRow, FinInterpTypes.FLAT_FORWARDS.value)
+                    t, vTimes, qRow, FinInterpTypes.FLAT_FWD_RATES.value)
 
             if model == FinLossDistributionBuilder.RECURSION:
                 qt1[i] = trSurvProbRecursion(
