@@ -17,7 +17,7 @@ from ...models.FinGBMProcess import getPaths
 
 from numba import njit
 
-from ...finutils.FinMath import N
+from ...finutils.FinMath import NVect
 
 ###############################################################################
 # TODO: Implement Sobol random numbers
@@ -166,7 +166,7 @@ class FinEquityOneTouchOption(FinEquityOption):
               valueDate: FinDate,
               stockPrice: (float, np.ndarray),
               discountCurve: FinDiscountCurve,
-              dividendYield: float,
+              dividendCurve: FinDiscountCurve,
               model):
         ''' Equity One-Touch Option valuation using the Black-Scholes model
         assuming a continuous (American) barrier from value date to expiry.
@@ -187,8 +187,8 @@ class FinEquityOneTouchOption(FinEquityOption):
         sqrtT = np.sqrt(t)
 
         df = discountCurve.df(self._expiryDate)
-        r = -np.log(df)/t
-        q = dividendYield
+        r = discountCurve.ccRate(self._expiryDate)
+        q = dividendCurve.ccRate(self._expiryDate)
 
         v = model._volatility
         v = max(v, 1e-6)
@@ -201,7 +201,6 @@ class FinEquityOneTouchOption(FinEquityOption):
         if DEBUG_MODE:
             print("t:", t)
             print("vol", v)
-            print("df", df)
             print("b", b)
             print("mu", mu)
             print("lam", lam)
@@ -214,8 +213,8 @@ class FinEquityOneTouchOption(FinEquityOption):
 
             eta = 1.0
             z = np.log(H/s0) / v / sqrtT + lam * v * sqrtT
-            A5_1 = np.power(H/s0, mu + lam) * N(eta * z)
-            A5_2 = np.power(H/s0, mu - lam) * N(eta * z - 2.0 * eta * lam * v * sqrtT)
+            A5_1 = np.power(H/s0, mu + lam) * NVect(eta * z)
+            A5_2 = np.power(H/s0, mu - lam) * NVect(eta * z - 2.0 * eta * lam * v * sqrtT)
             v = (A5_1 + A5_2) * K
             return v
 
@@ -227,8 +226,8 @@ class FinEquityOneTouchOption(FinEquityOption):
 
             eta = -1.0
             z = np.log(H/s0) / v / sqrtT + lam * v * sqrtT
-            A5_1 = np.power(H/s0, mu + lam) * N(eta * z)
-            A5_2 = np.power(H/s0, mu - lam) * N(eta * z - 2.0 * eta * lam * v * sqrtT)
+            A5_1 = np.power(H/s0, mu + lam) * NVect(eta * z)
+            A5_2 = np.power(H/s0, mu - lam) * NVect(eta * z - 2.0 * eta * lam * v * sqrtT)
             v = (A5_1 + A5_2) * K
             return v
 
@@ -241,8 +240,8 @@ class FinEquityOneTouchOption(FinEquityOption):
             eta = 1.0
             K = H
             z = np.log(H/s0) / v / sqrtT + lam * v * sqrtT
-            A5_1 = np.power(H/s0, mu + lam) * N(eta * z)
-            A5_2 = np.power(H/s0, mu - lam) * N(eta * z - 2.0 * eta * lam * v * sqrtT)
+            A5_1 = np.power(H/s0, mu + lam) * NVect(eta * z)
+            A5_2 = np.power(H/s0, mu - lam) * NVect(eta * z - 2.0 * eta * lam * v * sqrtT)
             v = (A5_1 + A5_2) * K
             return v
 
@@ -255,8 +254,8 @@ class FinEquityOneTouchOption(FinEquityOption):
             eta = -1.0
             K = H
             z = np.log(H/s0) / v / sqrtT + lam * v * sqrtT
-            A5_1 = np.power(H/s0, mu + lam) * N(eta * z)
-            A5_2 = np.power(H/s0, mu - lam) * N(eta * z - 2.0 * eta * lam * v * sqrtT)
+            A5_1 = np.power(H/s0, mu + lam) * NVect(eta * z)
+            A5_2 = np.power(H/s0, mu - lam) * NVect(eta * z - 2.0 * eta * lam * v * sqrtT)
             v = (A5_1 + A5_2) * K
             return v
 
@@ -270,8 +269,8 @@ class FinEquityOneTouchOption(FinEquityOption):
             phi = -1.0
             x2 = np.log(s0/H) / v / sqrtT + (mu + 1.0) * v * sqrtT
             y2 = np.log(H/s0) / v / sqrtT + (mu + 1.0) * v * sqrtT
-            B2 = K * df * N(phi*x2 - phi*v*sqrtT)
-            B4 = K * df * np.power(H/s0, 2.0 * mu) * N(eta*y2-eta*v*sqrtT)
+            B2 = K * df * NVect(phi*x2 - phi*v*sqrtT)
+            B4 = K * df * np.power(H/s0, 2.0 * mu) * NVect(eta*y2-eta*v*sqrtT)
             v = (B2 + B4)
             return v
 
@@ -286,8 +285,8 @@ class FinEquityOneTouchOption(FinEquityOption):
 
             x2 = np.log(s0/H) / v / sqrtT + (mu + 1.0) * v * sqrtT
             y2 = np.log(H/s0) / v / sqrtT + (mu + 1.0) * v * sqrtT
-            B2 = K * df * N(phi*x2 - phi*v*sqrtT)
-            B4 = K * df * np.power(H/s0, 2.0 * mu) * N(eta*y2-eta*v*sqrtT)
+            B2 = K * df * NVect(phi*x2 - phi*v*sqrtT)
+            B4 = K * df * np.power(H/s0, 2.0 * mu) * NVect(eta*y2-eta*v*sqrtT)
             v = (B2 + B4)
             return v
 
@@ -302,8 +301,8 @@ class FinEquityOneTouchOption(FinEquityOption):
             x2 = np.log(s0/H) / v / sqrtT + (mu + 1.0) * v * sqrtT
             y2 = np.log(H/s0) / v / sqrtT + (mu + 1.0) * v * sqrtT
             dq = np.exp(-q*t)
-            A2 = s0 * dq * N(phi*x2)
-            A4 = s0 * dq * np.power(H/s0, 2.0*(mu+1.0)) * N(eta*y2)
+            A2 = s0 * dq * NVect(phi*x2)
+            A4 = s0 * dq * np.power(H/s0, 2.0*(mu+1.0)) * NVect(eta*y2)
             v = (A2 + A4)
             return v
 
@@ -318,8 +317,8 @@ class FinEquityOneTouchOption(FinEquityOption):
             x2 = np.log(s0/H) / v / sqrtT + (mu + 1.0) * v * sqrtT
             y2 = np.log(H/s0) / v / sqrtT + (mu + 1.0) * v * sqrtT
             dq = np.exp(-q*t)
-            A2 = s0 * dq * N(phi*x2)
-            A4 = s0 * dq * np.power(H/s0, 2.0*(mu+1.0)) * N(eta*y2)
+            A2 = s0 * dq * NVect(phi*x2)
+            A4 = s0 * dq * np.power(H/s0, 2.0*(mu+1.0)) * NVect(eta*y2)
             v = (A2 + A4)
             return v
 
@@ -334,8 +333,8 @@ class FinEquityOneTouchOption(FinEquityOption):
 
             x2 = np.log(s0/H) / v / sqrtT + (mu + 1.0) * v * sqrtT
             y2 = np.log(H/s0) / v / sqrtT + (mu + 1.0) * v * sqrtT
-            B2 = K * df * N(phi*x2 - phi*v*sqrtT)
-            B4 = K * df * np.power(H/s0, 2.0 * mu) * N(eta*y2-eta*v*sqrtT)
+            B2 = K * df * NVect(phi*x2 - phi*v*sqrtT)
+            B4 = K * df * np.power(H/s0, 2.0 * mu) * NVect(eta*y2-eta*v*sqrtT)
             v = (B2 - B4)
             return v
 
@@ -350,8 +349,8 @@ class FinEquityOneTouchOption(FinEquityOption):
 
             x2 = np.log(s0/H) / v / sqrtT + (mu + 1.0) * v * sqrtT
             y2 = np.log(H/s0) / v / sqrtT + (mu + 1.0) * v * sqrtT
-            B2 = K * df * N(phi*x2 - phi*v*sqrtT)
-            B4 = K * df * np.power(H/s0, 2.0 * mu) * N(eta*y2-eta*v*sqrtT)
+            B2 = K * df * NVect(phi*x2 - phi*v*sqrtT)
+            B4 = K * df * np.power(H/s0, 2.0 * mu) * NVect(eta*y2-eta*v*sqrtT)
             v = (B2 - B4)
             return v
 
@@ -367,8 +366,8 @@ class FinEquityOneTouchOption(FinEquityOption):
             x2 = np.log(s0/H) / v / sqrtT + (mu + 1.0) * v * sqrtT
             y2 = np.log(H/s0) / v / sqrtT + (mu + 1.0) * v * sqrtT
             dq = np.exp(-q*t)
-            A2 = s0 * dq * N(phi*x2)
-            A4 = s0 * dq * np.power(H/s0, 2.0*(mu+1.0)) * N(eta*y2)
+            A2 = s0 * dq * NVect(phi*x2)
+            A4 = s0 * dq * np.power(H/s0, 2.0*(mu+1.0)) * NVect(eta*y2)
             v = (A2 - A4)
             return v
 
@@ -384,8 +383,8 @@ class FinEquityOneTouchOption(FinEquityOption):
             x2 = np.log(s0/H) / v / sqrtT + (mu + 1.0) * v * sqrtT
             y2 = np.log(H/s0) / v / sqrtT + (mu + 1.0) * v * sqrtT
             dq = np.exp(-q*t)
-            A2 = s0 * dq * N(phi*x2)
-            A4 = s0 * dq * np.power(H/s0, 2.0*(mu+1.0)) * N(eta*y2)
+            A2 = s0 * dq * NVect(phi*x2)
+            A4 = s0 * dq * np.power(H/s0, 2.0*(mu+1.0)) * NVect(eta*y2)
             v = (A2 - A4)
             return v
 
@@ -400,7 +399,7 @@ class FinEquityOneTouchOption(FinEquityOption):
                 valueDate: FinDate,
                 stockPrice: float,
                 discountCurve: FinDiscountCurve,
-                dividendYield: float,
+                dividendCurve: FinDiscountCurve,
                 model,
                 numPaths: int = 10000,
                 numStepsPerYear: int = 252,
@@ -411,13 +410,17 @@ class FinEquityOneTouchOption(FinEquityOption):
         convergence is slow. '''
 
         t = (self._expiryDate - valueDate) / gDaysInYear
+
         df = discountCurve.df(self._expiryDate)
         r = -np.log(df)/t
+
+        dq = dividendCurve.df(self._expiryDate)
+        q = -np.log(dq)/t
+
         numTimeSteps = int(t * numStepsPerYear) + 1
         dt = t / numTimeSteps
 
         v = model._volatility
-        q = dividendYield
         s0 = stockPrice
         mu = r - q
 
