@@ -4,12 +4,12 @@
 
 
 import numpy as np
+from numba import njit
 
-from scipy import optimize
-
+# from scipy import optimize
+from ...finutils.FinSolvers1D import newton_secant, bisection, newton
 
 from ...finutils.FinDate import FinDate
-from ...finutils.FinMath import nprime
 from ...finutils.FinGlobalVariables import gDaysInYear
 from ...finutils.FinError import FinError
 from ...finutils.FinGlobalTypes import FinOptionTypes
@@ -18,7 +18,15 @@ from ...market.curves.FinDiscountCurve import FinDiscountCurve
 
 from ...models.FinModel import FinModel
 from ...models.FinModelBlackScholes import FinModelBlackScholes
-from ...models.FinModelBlackScholesAnalytical import *
+from ...models.FinModelBlackScholesAnalytical import bsValue
+from ...models.FinModelBlackScholesAnalytical import bsDelta
+from ...models.FinModelBlackScholesAnalytical import bsVega
+from ...models.FinModelBlackScholesAnalytical import bsGamma
+from ...models.FinModelBlackScholesAnalytical import bsRho
+from ...models.FinModelBlackScholesAnalytical import bsTheta
+from ...models.FinModelBlackScholesAnalytical import bsImpliedVolatility
+from ...models.FinModelBlackScholesAnalytical import bsIntrinsic
+
 
 from ...models.FinModelBlackScholesMC import _valueMC_NONUMBA_NONUMPY
 from ...models.FinModelBlackScholesMC import _valueMC_NUMPY_NUMBA
@@ -28,13 +36,12 @@ from ...models.FinModelBlackScholesMC import _valueMC_NUMBA_PARALLEL
 
 from ...finutils.FinMath import N
 
-
 ###############################################################################
 
+@njit(fastmath=True, cache=True)
+def _f(v, args):
 
-def _f(v, *args):
-
-    self = args[0]
+    optionTypeValue = int(args[0])
     texp = args[1]
     s0 = args[2]
     r = args[3]
@@ -42,9 +49,8 @@ def _f(v, *args):
     k = args[5]
     price = args[6]
 
-    objFn = bsValue(s0, texp, k, r, q, v, self._optionType.value)
+    objFn = bsValue(s0, texp, k, r, q, v, optionTypeValue)
     objFn = objFn - price
-
     return objFn
 
 ###############################################################################
@@ -89,13 +95,46 @@ class FinEquityVanillaOption():
         self._numOptions = numOptions
         self._texp = None
 
+###############################################################################
+
+    def intrinsic(self,
+                  valueDate: (FinDate, list),
+                  stockPrice: (np.ndarray, float),
+                  discountCurve: FinDiscountCurve,
+                  dividendCurve: FinDiscountCurve):
+        ''' Equity Vanilla Option valuation using Black-Scholes model. '''
+
+        if type(valueDate) == FinDate:
+            texp = (self._expiryDate - valueDate) / gDaysInYear
+        else:
+            texp = valueDate
+
+        self._texp = texp
+
+        s0 = stockPrice
+        texp = np.maximum(texp, 1e-10)
+
+        df = discountCurve.df(self._expiryDate)
+        r = -np.log(df)/texp
+
+        dq = dividendCurve.df(self._expiryDate)
+        q = -np.log(dq)/texp
+
+        k = self._strikePrice
+
+        intrinsicValue = bsIntrinsic(s0, texp, k, r, q,
+                                     self._optionType.value)
+
+        intrinsicValue = intrinsicValue * self._numOptions
+        return intrinsicValue
+
 ###############################################################################
 
     def value(self,
               valueDate: (FinDate, list),
               stockPrice: (np.ndarray, float),
               discountCurve: FinDiscountCurve,
-              dividendYield: float,
+              dividendCurve: FinDiscountCurve,
               model: FinModel):
         ''' Equity Vanilla Option valuation using Black-Scholes model. '''
 
@@ -112,11 +151,16 @@ class FinEquityVanillaOption():
         if np.any(texp < 0.0):
             raise FinError("Time to expiry must be positive.")
 
-        texp = np.maximum(texp, 1e-10)
-        df = discountCurve.df(self._expiryDate)
         s0 = stockPrice
+
+        texp = np.maximum(texp, 1e-10)
+
+        df = discountCurve.df(self._expiryDate)
         r = -np.log(df)/texp
-        q = dividendYield
+
+        dq = dividendCurve.df(self._expiryDate)
+        q = -np.log(dq)/texp
+
         k = self._strikePrice
 
         if isinstance(model, FinModelBlackScholes):
@@ -136,7 +180,7 @@ class FinEquityVanillaOption():
               valueDate: FinDate,
               stockPrice: float,
               discountCurve: FinDiscountCurve,
-              dividendYield: float,
+              dividendCurve: FinDiscountCurve,
               model):
         ''' Calculate the analytical delta of a European vanilla option. '''
 
@@ -153,11 +197,15 @@ class FinEquityVanillaOption():
         if np.any(texp < 0.0):
             raise FinError("Time to expiry must be positive.")
 
-        texp = np.maximum(texp, 1e-10)
-        df = discountCurve.df(self._expiryDate)
         s0 = stockPrice
+        texp = np.maximum(texp, 1e-10)
+
+        df = discountCurve.df(self._expiryDate)
         r = -np.log(df)/texp
-        q = dividendYield
+
+        dq = dividendCurve.df(self._expiryDate)
+        q = -np.log(dq)/texp
+
         k = self._strikePrice
 
         if isinstance(model, FinModelBlackScholes):
@@ -176,7 +224,7 @@ class FinEquityVanillaOption():
               valueDate: FinDate,
               stockPrice: float,
               discountCurve: FinDiscountCurve,
-              dividendYield: float,
+              dividendCurve: FinDiscountCurve,
               model:FinModel):
         ''' Calculate the analytical gamma of a European vanilla option. '''
 
@@ -191,11 +239,16 @@ class FinEquityVanillaOption():
         if np.any(texp < 0.0):
             raise FinError("Time to expiry must be positive.")
 
-        texp = np.maximum(texp, 1e-10)
-        df = discountCurve.df(self._expiryDate)
         s0 = stockPrice
+
+        texp = np.maximum(texp, 1e-10)
+
+        df = discountCurve.df(self._expiryDate)
         r = -np.log(df)/texp
-        q = dividendYield
+
+        dq = dividendCurve.df(self._expiryDate)
+        q = -np.log(dq)/texp
+
         k = self._strikePrice
 
         if isinstance(model, FinModelBlackScholes):
@@ -214,7 +267,7 @@ class FinEquityVanillaOption():
              valueDate: FinDate,
              stockPrice: float,
              discountCurve: FinDiscountCurve,
-             dividendYield: float,
+             dividendCurve: FinDiscountCurve,
              model:FinModel):
         ''' Calculate the analytical vega of a European vanilla option. '''
 
@@ -229,11 +282,15 @@ class FinEquityVanillaOption():
         if np.any(texp < 0.0):
             raise FinError("Time to expiry must be positive.")
 
-        texp = np.maximum(texp, 1e-10)
-        df = discountCurve.df(self._expiryDate)
         s0 = stockPrice
+        texp = np.maximum(texp, 1e-10)
+
+        df = discountCurve.df(self._expiryDate)
         r = -np.log(df)/texp
-        q = dividendYield
+
+        dq = dividendCurve.df(self._expiryDate)
+        q = -np.log(dq)/texp
+
         k = self._strikePrice
 
         if isinstance(model, FinModelBlackScholes):
@@ -252,7 +309,7 @@ class FinEquityVanillaOption():
               valueDate: FinDate,
               stockPrice: float,
               discountCurve: FinDiscountCurve,
-              dividendYield: float,
+              dividendCurve: FinDiscountCurve,
               model:FinModel):
         ''' Calculate the analytical theta of a European vanilla option. '''
 
@@ -267,11 +324,15 @@ class FinEquityVanillaOption():
         if np.any(texp < 0.0):
             raise FinError("Time to expiry must be positive.")
 
-        texp = np.maximum(texp, 1e-10)
-        df = discountCurve.df(self._expiryDate)
         s0 = stockPrice
+        texp = np.maximum(texp, 1e-10)
+
+        df = discountCurve.df(self._expiryDate)
         r = -np.log(df)/texp
-        q = dividendYield
+
+        dq = dividendCurve.df(self._expiryDate)
+        q = -np.log(dq)/texp
+
         k = self._strikePrice
 
         if isinstance(model, FinModelBlackScholes):
@@ -290,7 +351,7 @@ class FinEquityVanillaOption():
             valueDate: FinDate,
             stockPrice: float,
             discountCurve: FinDiscountCurve,
-            dividendYield: float,
+            dividendCurve: FinDiscountCurve,
             model:FinModel):
         ''' Calculate the analytical rho of a European vanilla option. '''
 
@@ -305,11 +366,15 @@ class FinEquityVanillaOption():
         if np.any(texp < 0.0):
             raise FinError("Time to expiry must be positive.")
 
-        texp = np.maximum(texp, 1e-10)
-        df = discountCurve.df(self._expiryDate)
         s0 = stockPrice
+        texp = np.maximum(texp, 1e-10)
+
+        df = discountCurve.df(self._expiryDate)
         r = -np.log(df)/texp
-        q = dividendYield
+
+        dq = dividendCurve.df(self._expiryDate)
+        q = -np.log(dq)/texp
+
         k = self._strikePrice
 
         if isinstance(model, FinModelBlackScholes):
@@ -328,22 +393,29 @@ class FinEquityVanillaOption():
                           valueDate: FinDate,
                           stockPrice: (float, list, np.ndarray),
                           discountCurve: FinDiscountCurve,
-                          dividendYield: float,
+                          dividendCurve: FinDiscountCurve,
                           price):
-        ''' Calculate the implied volatility of a European vanilla option. '''
+        ''' Calculate the Black-Scholes implied volatility of a European 
+        vanilla option. '''
 
         texp = (self._expiryDate - valueDate) / gDaysInYear
-        texp = np.maximum(texp, 1e-10)
+
+        if texp < 1.0 / 365.0:
+            print("Expiry time is too close to zero.")
+            return -999
+
         df = discountCurve.df(self._expiryDate)
         r = -np.log(df)/texp
-        q = dividendYield
+
+        dq = dividendCurve.df(self._expiryDate)
+        q = -np.log(dq)/texp
+
         k = self._strikePrice
         s0 = stockPrice
 
-        argtuple = (self, texp, s0, r, q, k, price)
-
-        sigma = optimize.newton(_f, x0=0.2, fprime=_fvega, args=argtuple,
-                                tol=1e-5, maxiter=50, fprime2=None)
+        sigma = bsImpliedVolatility(s0, texp, k, r, q, price, 
+                                    self._optionType.value)
+        
         return sigma
 
 ###############################################################################
@@ -352,23 +424,28 @@ class FinEquityVanillaOption():
                            valueDate: FinDate,
                            stockPrice: float,
                            discountCurve: FinDiscountCurve,
-                           dividendYield: float,
+                           dividendCurve: FinDiscountCurve,
                            model:FinModel,
                            numPaths: int = 10000,
                            seed: int = 4242,
                            useSobol: int = 0):
 
-        t = (self._expiryDate - valueDate) / gDaysInYear
+        texp = (self._expiryDate - valueDate) / gDaysInYear
+
         df = discountCurve.df(self._expiryDate)
-        r = -np.log(df)/t
+        r = -np.log(df)/texp
+
+        dq = dividendCurve.df(self._expiryDate)
+        q = -np.log(dq)/texp
+
         vol = model._volatility
 
         v = _valueMC_NUMPY_ONLY(stockPrice, 
-                           t, 
+                           texp, 
                            self._strikePrice,
                            self._optionType.value,
                            r, 
-                           dividendYield, 
+                           q, 
                            vol, 
                            numPaths, 
                            seed,
@@ -382,23 +459,28 @@ class FinEquityVanillaOption():
                            valueDate: FinDate,
                            stockPrice: float,
                            discountCurve: FinDiscountCurve,
-                           dividendYield: float,
+                           dividendCurve: FinDiscountCurve,
                            model:FinModel,
                            numPaths: int = 10000,
                            seed: int = 4242,
                            useSobol: int = 0):
 
-        t = (self._expiryDate - valueDate) / gDaysInYear
+        texp = (self._expiryDate - valueDate) / gDaysInYear
+
         df = discountCurve.df(self._expiryDate)
-        r = -np.log(df)/t
+        r = -np.log(df)/texp
+
+        dq = dividendCurve.df(self._expiryDate)
+        q = -np.log(dq)/texp
+
         vol = model._volatility
 
         v = _valueMC_NUMBA_ONLY(stockPrice, 
-                           t, 
+                           texp, 
                            self._strikePrice,
                            self._optionType.value,
                            r, 
-                           dividendYield, 
+                           q, 
                            vol, 
                            numPaths, 
                            seed, 
@@ -412,23 +494,28 @@ class FinEquityVanillaOption():
                            valueDate: FinDate,
                            stockPrice: float,
                            discountCurve: FinDiscountCurve,
-                           dividendYield: float,
+                           dividendCurve: FinDiscountCurve,
                            model:FinModel,
                            numPaths: int = 10000,
                            seed: int = 4242,
                            useSobol: int = 0):
 
-        t = (self._expiryDate - valueDate) / gDaysInYear
+        texp = (self._expiryDate - valueDate) / gDaysInYear
+
         df = discountCurve.df(self._expiryDate)
-        r = -np.log(df)/t
+        r = -np.log(df)/texp
+
+        dq = dividendCurve.df(self._expiryDate)
+        q = -np.log(dq)/texp
+
         vol = model._volatility
 
         v = _valueMC_NUMBA_PARALLEL(stockPrice, 
-                           t, 
+                           texp, 
                            self._strikePrice,
                            self._optionType.value,
                            r, 
-                           dividendYield, 
+                           q, 
                            vol, 
                            numPaths, 
                            seed, 
@@ -444,23 +531,28 @@ class FinEquityVanillaOption():
                       valueDate: FinDate,
                       stockPrice: float,
                       discountCurve: FinDiscountCurve,
-                      dividendYield: float,
+                      dividendCurve: FinDiscountCurve,
                       model:FinModel,
                       numPaths: int = 10000,
                       seed: int = 4242,
                       useSobol: int = 0):
 
-        t = (self._expiryDate - valueDate) / gDaysInYear
+        texp = (self._expiryDate - valueDate) / gDaysInYear
+
         df = discountCurve.df(self._expiryDate)
-        r = -np.log(df)/t
+        r = -np.log(df)/texp
+
+        dq = dividendCurve.df(self._expiryDate)
+        q = -np.log(dq)/texp
+
         vol = model._volatility
 
         v = _valueMC_NUMPY_NUMBA(stockPrice, 
-                           t, 
+                           texp, 
                            self._strikePrice,
                            self._optionType.value,
                            r, 
-                           dividendYield, 
+                           q, 
                            vol, 
                            numPaths, 
                            seed,
@@ -474,23 +566,28 @@ class FinEquityVanillaOption():
                       valueDate: FinDate,
                       stockPrice: float,
                       discountCurve: FinDiscountCurve,
-                      dividendYield: float,
+                      dividendCurve: FinDiscountCurve,
                       model:FinModel,
                       numPaths: int = 10000,
                       seed: int = 4242,
                       useSobol: int = 0):
 
-        t = (self._expiryDate - valueDate) / gDaysInYear
+        texp = (self._expiryDate - valueDate) / gDaysInYear
+
         df = discountCurve.df(self._expiryDate)
-        r = -np.log(df)/t
+        r = -np.log(df)/texp
+
+        dq = dividendCurve.df(self._expiryDate)
+        q = -np.log(dq)/texp
+
         vol = model._volatility
 
         v = _valueMC_NONUMBA_NONUMPY(stockPrice, 
-                           t, 
+                           texp, 
                            self._strikePrice,
                            self._optionType.value,
                            r, 
-                           dividendYield, 
+                           q, 
                            vol, 
                            numPaths, 
                            seed,
@@ -504,7 +601,7 @@ class FinEquityVanillaOption():
                 valueDate: FinDate,
                 stockPrice: float,
                 discountCurve: FinDiscountCurve,
-                dividendYield: float,
+                dividendCurve: FinDiscountCurve,
                 model:FinModel,
                 numPaths: int = 10000,
                 seed: int = 4242,
@@ -512,17 +609,22 @@ class FinEquityVanillaOption():
         ''' Value European style call or put option using Monte Carlo. This is
         mainly for educational purposes. Sobol numbers can be used. '''
 
-        t = (self._expiryDate - valueDate) / gDaysInYear
+        texp = (self._expiryDate - valueDate) / gDaysInYear
+
         df = discountCurve.df(self._expiryDate)
-        r = -np.log(df)/t
+        r = -np.log(df)/texp
+
+        dq = dividendCurve.df(self._expiryDate)
+        q = -np.log(dq)/texp
+
         vol = model._volatility
 
         v = _valueMC_NUMBA_ONLY(stockPrice, 
-                           t, 
+                           texp, 
                            self._strikePrice,
                            self._optionType.value,
                            r, 
-                           dividendYield, 
+                           q, 
                            vol, 
                            numPaths, 
                            seed, 
