@@ -1,11 +1,9 @@
 from .FinFXBarrierOption import *
-from .FinFXBasketOption import *
 from .FinFXDigitalOption import *
 from .FinFXFixedLookbackOption import *
 from .FinFXFloatLookbackOption import *
 from .FinFXForward import *
 from .FinFXMktConventions import *
-from .FinFXModelTypes import *
 from .FinFXOption import *
 from .FinFXRainbowOption import *
 from .FinFXVanillaOption import *
