@@ -10,7 +10,7 @@ from ...finutils.FinDate import FinDate
 from ...finutils.FinHelperFunctions import labelToString
 from ...finutils.FinHelperFunctions import checkArgumentTypes, _funcName
 from ...finutils.FinGlobalVariables import gDaysInYear
-from ...market.curves.FinInterpolate import FinInterpTypes
+from ...market.curves.FinInterpolator import FinInterpTypes
 from ...market.curves.FinDiscountCurve import FinDiscountCurve
 
 swaptol = 1e-8
@@ -26,7 +26,7 @@ def _f(df, *args):
     valueDate = args[1]
     swap = args[2]
     numPoints = len(curve._times)
-    curve._dfValues[numPoints - 1] = df
+    curve._dfs[numPoints - 1] = df
     v_swap = swap.value(valueDate, curve, curve, None, 1.0)
     v_swap /= swap._notional
     return v_swap
@@ -40,7 +40,7 @@ def _g(df, *args):
     valueDate = args[1]
     fra = args[2]
     numPoints = len(curve._times)
-    curve._dfValues[numPoints - 1] = df
+    curve._dfs[numPoints - 1] = df
     v_fra = fra.value(valueDate, curve)
     v_fra /= fra._notional
     return v_fra
@@ -82,7 +82,7 @@ class FinInflationSwapCurve(FinDiscountCurve):
                  iborDeposits: list,
                  iborFRAs: list,
                  iborSwaps: list,
-                 interpType: FinInterpTypes = FinInterpTypes.LINEAR_SWAP_RATES,
+                 interpType: FinInterpTypes = FinInterpTypes.FLAT_FWD_RATES,
                  checkRefit: bool = False):  # Set to True to test it works
         ''' Create an instance of a FinIbor curve given a valuation date and
         a set of ibor deposits, ibor FRAs and iborSwaps. Some of these may
@@ -107,10 +107,7 @@ class FinInflationSwapCurve(FinDiscountCurve):
 
     def _buildCurve(self):
         ''' Build curve based on interpolation. '''
-        if self._interpType == FinInterpTypes.LINEAR_SWAP_RATES:
-            self._buildCurveLinearSwapRateInterpolation()
-        else:
-            self._buildCurveUsingSolver()
+        self._buildCurveUsingSolver()
 
 ###############################################################################
 
@@ -245,20 +242,20 @@ class FinInflationSwapCurve(FinDiscountCurve):
         involves the use of a solver. '''
 
         self._times = np.array([])
-        self._dfValues = np.array([])
+        self._dfs = np.array([])
 
         # time zero is now.
         tmat = 0.0
         dfMat = 1.0
         self._times = np.append(self._times, 0.0)
-        self._dfValues = np.append(self._dfValues, dfMat)
+        self._dfs = np.append(self._dfs, dfMat)
 
         for depo in self._usedDeposits:
             dfSettle = self.df(depo._startDate)
             dfMat = depo._maturityDf() * dfSettle
             tmat = (depo._maturityDate - self._valuationDate) / gDaysInYear
             self._times = np.append(self._times, tmat)
-            self._dfValues = np.append(self._dfValues, dfMat)
+            self._dfs = np.append(self._dfs, dfMat)
 
         oldtmat = tmat
 
@@ -273,10 +270,10 @@ class FinInflationSwapCurve(FinDiscountCurve):
             if tset < oldtmat and tmat > oldtmat:
                 dfMat = fra.maturityDf(self)
                 self._times = np.append(self._times, tmat)
-                self._dfValues = np.append(self._dfValues, dfMat)
+                self._dfs = np.append(self._dfs, dfMat)
             else:
                 self._times = np.append(self._times, tmat)
-                self._dfValues = np.append(self._dfValues, dfMat)
+                self._dfs = np.append(self._dfs, dfMat)
 
                 argtuple = (self, self._valuationDate, fra)
                 dfMat = optimize.newton(_g, x0=dfMat, fprime=None,
@@ -290,7 +287,7 @@ class FinInflationSwapCurve(FinDiscountCurve):
             tmat = (maturityDate - self._valuationDate) / gDaysInYear
 
             self._times = np.append(self._times, tmat)
-            self._dfValues = np.append(self._dfValues, dfMat)
+            self._dfs = np.append(self._dfs, dfMat)
 
             argtuple = (self, self._valuationDate, swap)
 
@@ -309,20 +306,20 @@ class FinInflationSwapCurve(FinDiscountCurve):
         require the use of a solver. It is also market standard. '''
 
         self._times = np.array([])
-        self._dfValues = np.array([])
+        self._dfs = np.array([])
 
         # time zero is now.
         tmat = 0.0
         dfMat = 1.0
         self._times = np.append(self._times, 0.0)
-        self._dfValues = np.append(self._dfValues, dfMat)
+        self._dfs = np.append(self._dfs, dfMat)
 
         for depo in self._usedDeposits:
             dfSettle = self.df(depo._startDate)
             dfMat = depo._maturityDf() * dfSettle
             tmat = (depo._maturityDate - self._valuationDate) / gDaysInYear
             self._times = np.append(self._times, tmat)
-            self._dfValues = np.append(self._dfValues, dfMat)
+            self._dfs = np.append(self._dfs, dfMat)
 
         oldtmat = tmat
 
@@ -337,10 +334,10 @@ class FinInflationSwapCurve(FinDiscountCurve):
             if tset < oldtmat and tmat > oldtmat:
                 dfMat = fra.maturityDf(self)
                 self._times = np.append(self._times, tmat)
-                self._dfValues = np.append(self._dfValues, dfMat)
+                self._dfs = np.append(self._dfs, dfMat)
             else:
                 self._times = np.append(self._times, tmat)
-                self._dfValues = np.append(self._dfValues, dfMat)
+                self._dfs = np.append(self._dfs, dfMat)
 
                 argtuple = (self, self._valuationDate, fra)
                 dfMat = optimize.newton(_g, x0=dfMat, fprime=None,
@@ -354,7 +351,7 @@ class FinInflationSwapCurve(FinDiscountCurve):
 
 #        print("CURVE SO FAR")
 #        print(self._times)
-#        print(self._dfValues)
+#        print(self._dfs)
 
         #######################################################################
         # ADD SWAPS TO CURVE
@@ -443,12 +440,12 @@ class FinInflationSwapCurve(FinDiscountCurve):
 #                  (dt, swapRate, acc, pv01, pv01End, dfMat))
 
             self._times = np.append(self._times, tmat)
-            self._dfValues = np.append(self._dfValues, dfMat)
+            self._dfs = np.append(self._dfs, dfMat)
 
             pv01 += acc * dfMat
 
 #        print(self._times)
-#        print(self._dfValues)
+#        print(self._dfs)
 
         if self._checkRefit is True:
             self._checkRefits(1e-10, swaptol, 1e-5)
@@ -508,7 +505,7 @@ class FinInflationSwapCurve(FinDiscountCurve):
         s += labelToString("GRID TIMES", "GRID DFS")
         for i in range(0, numPoints):
             s += labelToString("% 10.6f" % self._times[i],
-                               "%12.10f" % self._dfValues[i])
+                               "%12.10f" % self._dfs[i])
 
         return s
 
