@@ -5,13 +5,13 @@
 import sys
 sys.path.append("..")
 
-from financepy.products.funding.FinIborSingleCurve import FinIborSingleCurve
+from financepy.products.rates.FinIborSingleCurve import FinIborSingleCurve
 from financepy.products.bonds.FinBondFRN import FinBondFRN
 from financepy.finutils.FinFrequency import FinFrequencyTypes
 from financepy.finutils.FinDayCount import FinDayCountTypes
-from financepy.finutils.FinDate import FinDate
-from financepy.products.funding.FinIborSwap import FinIborSwap
-from financepy.products.funding.FinIborDeposit import FinIborDeposit
+from financepy.finutils.FinDate import *
+from financepy.products.rates.FinIborSwap import FinIborSwap
+from financepy.products.rates.FinIborDeposit import FinIborDeposit
 from financepy.finutils.FinGlobalTypes import FinSwapTypes
 
 from FinTestCases import FinTestCases, globalTestCaseMode
