@@ -8,9 +8,9 @@ import sys
 sys.path.append("..")
 
 from financepy.products.credit.FinCDS import FinCDS
-from financepy.products.funding.FinIborSwap import FinIborSwap
+from financepy.products.rates.FinIborSwap import FinIborSwap
 from financepy.products.credit.FinCDSCurve import FinCDSCurve
-from financepy.products.funding.FinIborSingleCurve import FinIborSingleCurve
+from financepy.products.rates.FinIborSingleCurve import FinIborSingleCurve
 from financepy.finutils.FinFrequency import FinFrequencyTypes
 from financepy.finutils.FinDayCount import FinDayCountTypes
 from financepy.finutils.FinDate import FinDate
@@ -24,7 +24,7 @@ testCases = FinTestCases(__file__, globalTestCaseMode)
 
 def test_FinCDSCurve():
 
-    curveDate = FinDate(2018, 12, 20)
+    curveDate = FinDate(20, 12, 2018)
 
     swaps = []
     depos = []
@@ -37,13 +37,12 @@ def test_FinCDSCurve():
     for i in range(1, 11):
 
         maturityDate = curveDate.addMonths(12 * i)
-        swap = FinIborSwap(
-            curveDate,
-            maturityDate,
-            FinSwapTypes.PAY,
-            fixedCoupon,
-            fixedFreq,
-            fixedDCC)
+        swap = FinIborSwap(curveDate,
+                           maturityDate,
+                           FinSwapTypes.PAY,
+                           fixedCoupon,
+                           fixedFreq,
+                           fixedDCC)
         swaps.append(swap)
 
     libor_curve = FinIborSingleCurve(curveDate, depos, fras, swaps)
