@@ -18,10 +18,9 @@ testCases = FinTestCases(__file__, globalTestCaseMode)
 ###############################################################################
 
 
-def test_FinEquityCliquetOptionHaug():
-    ''' Following example in Haug Page 130 '''
+def test_FinEquityCliquetOption():
 
-    startDate = FinDate(1, 1, 2015)
+    startDate = FinDate(1, 1, 2014)
     finalExpiryDate = FinDate(1, 1, 2017)
     freqType = FinFrequencyTypes.QUARTERLY
     optionType = FinOptionTypes.EUROPEAN_CALL
@@ -31,18 +30,19 @@ def test_FinEquityCliquetOptionHaug():
                                            optionType,
                                            freqType)
 
-    valueDate = FinDate(1, 8, 2016)
-    stockPrice = 50.0
-    volatility = 0.35
-    interestRate = 0.10
-    dividendYield = 0.05
+    valueDate = FinDate(1, 1, 2015)
+    stockPrice = 100.0
+    volatility = 0.20
+    interestRate = 0.05
+    dividendYield = 0.02
     model = FinModelBlackScholes(volatility)
     discountCurve = FinDiscountCurveFlat(valueDate, interestRate)
+    dividendCurve = FinDiscountCurveFlat(valueDate, dividendYield)
 
     v = cliquetOption.value(valueDate,
                             stockPrice,
                             discountCurve,
-                            dividendYield,
+                            dividendCurve,
                             model)
 
     testCases.header("LABEL", "VALUE")
@@ -51,5 +51,5 @@ def test_FinEquityCliquetOptionHaug():
 ###############################################################################
 
 
-test_FinEquityCliquetOptionHaug()
+test_FinEquityCliquetOption()
 testCases.compareTestCases()
