@@ -10,11 +10,11 @@ import sys
 sys.path.append("..")
 
 from financepy.finutils.FinGlobalTypes import FinCapFloorTypes
-from financepy.products.funding.FinIborCapFloor import FinIborCapFloor
-from financepy.products.funding.FinIborSwap import FinIborSwap
-from financepy.products.funding.FinIborSwap import FinSwapTypes
-from financepy.products.funding.FinIborDeposit import FinIborDeposit
-from financepy.products.funding.FinIborSingleCurve import FinIborSingleCurve
+from financepy.products.rates.FinIborCapFloor import FinIborCapFloor
+from financepy.products.rates.FinIborSwap import FinIborSwap
+from financepy.products.rates.FinIborSwap import FinSwapTypes
+from financepy.products.rates.FinIborDeposit import FinIborDeposit
+from financepy.products.rates.FinIborSingleCurve import FinIborSingleCurve
 
 from financepy.finutils.FinFrequency import FinFrequencyTypes
 from financepy.finutils.FinDayCount import FinDayCountTypes
@@ -298,7 +298,7 @@ def test_FinIborCapletHull():
                                            model)
 
     # Cannot match Hull due to dates being adjusted
-    testCases.header("CORRECT PRICE", "MODEL PRICE")
+    testCases.header("CORRECT PRICE", "MODEL_PRICE")
     testCases.print(517.29, vCaplet)
 
 ###############################################################################
@@ -330,7 +330,7 @@ def test_FinIborCapFloorQLExample():
 
     startDate = FinDate(14, 6, 2016)
     endDate = FinDate(14, 6, 2026)
-    calendarType = FinCalendarTypes.US
+    calendarType = FinCalendarTypes.UNITED_STATES
     busDayAdjustType = FinBusDayAdjustTypes.MODIFIED_FOLLOWING
     freqType = FinFrequencyTypes.QUARTERLY
     dateGenRuleType = FinDateGenRuleTypes.FORWARD
