@@ -5,12 +5,14 @@
 import sys
 sys.path.append("..")
 
-from financepy.products.funding.FinIborFuture import FinIborFuture
-from financepy.finutils.FinDate import FinDate
+from financepy.products.rates.FinIborFuture import FinIborFuture
+from financepy.finutils.FinDate import *
 
 from FinTestCases import FinTestCases, globalTestCaseMode
 testCases = FinTestCases(__file__, globalTestCaseMode)
 
+setDateFormatType(FinDateFormatTypes.UK_LONG)
+
 ###############################################################################
 
 
