@@ -2,13 +2,12 @@
 # Copyright (C) 2018, 2019, 2020 Dominic O'Kane
 ###############################################################################
 
-import sys
 import numpy as np
 
+import sys
+sys.path.append("..")
+
 from FinTestCases import FinTestCases, globalTestCaseMode
-
-sys.path.append("..//..")
-
 testCases = FinTestCases(__file__, globalTestCaseMode)
 
 ##########################################################################
